=== modified file 'NEWS'
--- NEWS	2010-03-18 09:20:09 +0000
+++ NEWS	2010-06-04 12:25:04 +0000
@@ -10,8 +10,14 @@
    * Don't crash when there is already a lan-notify instance running.
      (Jelmer Vernooij, #339284)
 
+   * Return the credentials if successfully found in gnome-keyring.
+     (John Szakmeister)
+
 FEATURES
 
+  * Add 'Find' button to start text search.
+    (Martin Pool, #556347)
+
   * Add 'glog' as an alias for visualize (aka viz) as too many
     people are still confused.
     (Vincent Ladeuil)

=== modified file 'annotate/gannotate.py'
--- annotate/gannotate.py	2009-06-05 12:18:50 +0000
+++ annotate/gannotate.py	2010-05-27 02:28:54 +0000
@@ -212,6 +212,10 @@
         hbox.pack_start(self.back_button, expand=False, fill=True)
         self.forward_button = self._create_forward_button()
         hbox.pack_start(self.forward_button, expand=False, fill=True)
+        self.find_button = self._create_find_button()
+        hbox.pack_start(self.find_button, expand=False, fill=True)
+        self.goto_button = self._create_goto_button()
+        hbox.pack_start(self.goto_button, expand=False, fill=True)
         hbox.show()
         vbox.pack_start(hbox, expand=False, fill=True)
         
@@ -234,11 +238,11 @@
 
         self.add(vbox)
 
-    def _search_by_text(self, accel_group, window, key, modifiers):
+    def _search_by_text(self, *ignored): # (accel_group, window, key, modifiers):
         self._search.show_for('text')
         self._search.set_target(self.annoview, TEXT_LINE_COL)
 
-    def _search_by_line(self, accel_group, window, key, modifiers):
+    def _search_by_line(self, *ignored): # accel_group, window, key, modifiers):
         self._search.show_for('line')
         self._search.set_target(self.annoview, LINE_NUM_COL)
 
@@ -344,6 +348,27 @@
         button.set_sensitive(False)
         return button
 
+    def _create_find_button(self):
+        button = gtk.Button()
+        button.set_use_stock(True)
+        button.set_label("gtk-find")
+        button.set_tooltip_text("Search for text (Ctrl+F)")
+        button.connect("clicked", self._search_by_text)
+        button.set_relief(gtk.RELIEF_NONE)
+        button.show()
+        button.set_sensitive(True)
+        return button
+
+    def _create_goto_button(self):
+        button = gtk.Button()
+        button.set_label("Goto Line")
+        button.set_tooltip_text("Scroll to a line by entering its number (Ctrl+G)")
+        button.connect("clicked", self._search_by_line)
+        button.set_relief(gtk.RELIEF_NONE)
+        button.show()
+        button.set_sensitive(True)
+        return button
+
     def go_back(self):
         last_tree = self.tree
         rev_id = self._selected_revision()

=== modified file 'commands.py'
--- commands.py	2010-05-29 23:45:35 +0000
+++ commands.py	2010-06-17 20:25:04 +0000
@@ -199,6 +199,9 @@
     """GTK+ annotate.
     
     Browse changes to FILENAME line by line in a GTK+ window.
+
+    Within the annotate window, you can use Ctrl-F to search for text, and 
+    Ctrl-G to jump to a line by number.
     """
 
     takes_args = ["filename", "line?"]

=== modified file 'keyring.py'
--- keyring.py	2010-03-09 01:21:41 +0000
+++ keyring.py	2010-06-04 12:12:59 +0000
@@ -77,6 +77,7 @@
                 gnomekeyring.ITEM_NETWORK_PASSWORD, attrs)
             credentials["user"] = items[0].attributes["user"]
             credentials["password"] = items[0].secret
+            return credentials
         except (gnomekeyring.NoMatchError, gnomekeyring.DeniedError, gnomekeyring.NoKeyringDaemonError,
                 gnomekeyring.IOError), e:
             from bzrlib import trace

